==> mysql-boost-8.0.28.tar.gz: mysql-8.0.28/client/dump/thread_group.cc <==
/*
  Copyright (c) 2015, 2021, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include "client/dump/thread_group.h"

void my_boost::thread_group::join_all() {
  for (std::vector<my_boost::thread *>::iterator it = m_threads.begin();
       it != m_threads.end(); ++it) {
    (*it)->join();
  }
}

my_boost::thread_group::~thread_group() {
  for (std::vector<my_boost::thread *>::iterator it = m_threads.begin();
       it != m_threads.end(); ++it) {
    delete *it;
  }
}

==> mysql-boost-8.0.41.tar.gz: mysql-8.0.41/client/dump/thread_group.cc <==
/*
  Copyright (c) 2015, 2024, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is designed to work with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have either included with
  the program or referenced in the documentation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include "client/dump/thread_group.h"

void my_boost::thread_group::join_all() {
  for (std::vector<my_boost::thread *>::iterator it = m_threads.begin();
       it != m_threads.end(); ++it) {
    (*it)->join();
  }
}

my_boost::thread_group::~thread_group() {
  for (std::vector<my_boost::thread *>::iterator it = m_threads.begin();
       it != m_threads.end(); ++it) {
    delete *it;
  }
}
